# GLaDOS - Slack Bot Framework 
GLaDOS is a Slack bot plugin framework for interactive slack bots. 


## Installation
The easiest way to install GLaDOS is using pip:
```bash
pip3 install glados
```

## Example GLaDOS Server

## AWS Deployment
### Lambda
### API Gateway
### Terraform

## Docker

## Plugins Available 

## Installation

## [Documentation](https://zpriddy.github.io/GLaDOS/index.html) 